==> 0.0.3.tar.gz: ios/Classes/PlayerFlutterView.swift <==
//
//  PlayerFlutterView.swift
//  KalturaNetKit
//

import Flutter
import PlayKit
import PlayKitProviders

final class PlayerFlutterViewFactory: NSObject, FlutterPlatformViewFactory {

  static let factoryIdentifier: String = "plugins.video_360_kaltura/player_view"

  private let messenger: FlutterBinaryMessenger

  init(messenger: FlutterBinaryMessenger) {
    self.messenger = messenger
    super.init()
  }

  func create(withFrame frame: CGRect, viewIdentifier viewId: Int64, arguments args: Any?) -> FlutterPlatformView {

    let playerFlutterView = PlayerFlutterView(
      frame: frame,
      viewId: viewId,
      arguments: args as? [String : Any],
      messenger: messenger
    )

    return playerFlutterView
  }

  func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
    return FlutterStandardMessageCodec.sharedInstance()
  }

}

final class PlayerFlutterView: NSObject, FlutterPlatformView {

  private let viewId: Int64

  private let args: Dictionary<String, Any>?
  private let serverUrl: String?
  private let partnerID: String?

  private let player: Player = PlayKitManager.shared.loadPlayer(pluginConfig: nil)
  private let flutterView: PlayerView

  private let channel: FlutterMethodChannel
  private let flutterChannels: [KalturaFlutterEventChannel]

  init(frame: CGRect, viewId: Int64, arguments: [String: Any]?, messenger: FlutterBinaryMessenger) {
    self.viewId = viewId;
    self.args = arguments

    self.serverUrl = arguments?["ovpServerUrl"] as? String
    self.partnerID = arguments?["partnerId"] as? String

    self.channel = FlutterMethodChannel(
      name: String(format: "video360Kaltura_%lld", viewId),
      binaryMessenger: messenger
    )

    flutterChannels = [
      KalturaFlutterEventChannel(
        name: String(format: "video360Kaltura_events_%lld_state", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: [PlayerEvent.stateChanged]
      ),
      KalturaFlutterEventChannel(
        name: String(format: "video360Kaltura_events_%lld_duration", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: [PlayerEvent.durationChanged]
      ),
      KalturaFlutterEventChannel(
        name: String(format: "video360Kaltura_events_%lld_position", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: PlayerEvent.allEventTypes
      ),
      KalturaFlutterEventChannel(
        name: String(format: "video360Kaltura_events_%lld_ended", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: [PlayerEvent.ended]
      )
    ]

    let viewFrame = CGRect(
      x: CGFloat(args?["x"] as? Double ?? 0.0),
      y: CGFloat(args?["y"] as? Double ?? 0.0),
      width: CGFloat(args?["width"] as? Double ?? 0.0),
      height: CGFloat(args?["height"] as? Double ?? 0.0)
    )

    flutterView = PlayerView(frame: viewFrame)
    player.view = flutterView

    super.init()

    self.channel.setMethodCallHandler(methodCallback)
  }

  func view() -> UIView {
    return flutterView
  }

  //MARK: FlutterMethodChannel
  func methodCallback(call: FlutterMethodCall, result: FlutterResult)  {

    #if DEBUG
    NSLog("ios: FlutterMethod %@ - Arguments -> %@", call.method, call.arguments.debugDescription)
    #endif

    switch call.method {
    case "loadVideo":
      loadVideo(arguments: call.arguments as? [String: Any], result: result)
    case "onOrientationChanged":
      onOrientationChanged(arguments: call.arguments, result: result)
    case "onSizeChanged":
      onSizeChanged(arguments: call.arguments, result: result)
    case "isPlaying":
      isPlaying(arguments: call.arguments, result: result)
    case "play":
      play(arguments: call.arguments, result: result)
    case "pause":
      pause(arguments: call.arguments, result: result)
    case "toggleVRMode":
      toggleVRMode(arguments: call.arguments, result: result)
    case "seekTo":
      seekTo(arguments: call.arguments, result: result)
    case "onPause":
      onPause(arguments: call.arguments, result: result)
    case "onResume":
      onResume(arguments: call.arguments, result: result)
    default:
      methodCall(arguments: call.arguments, result: result)
    }
  }

  private func methodCall(arguments: Any?, result: FlutterResult) {
    result(FlutterMethodNotImplemented)
  }

  private func loadVideo(arguments: [String: Any]?, result: FlutterResult) {

    PlayKitManager.logLevel = .info

    guard let serverUrl = serverUrl else {
      result(FlutterError(code: "Server URL is required", message: nil, details: nil))
      return
    }

    guard let partnerID = partnerID else {
      result(FlutterError(code: "Partner Identifier is required", message: nil, details: nil))
      return
    }

    let sessionProvider: SimpleSessionProvider = SimpleSessionProvider(
      serverURL: serverUrl,
      partnerId: Int64(partnerID) ?? 0,
      ks: nil
    )

    let mediaProvider: OVPMediaProvider = OVPMediaProvider(sessionProvider)
    mediaProvider.set(entryId: arguments?["entryId"] as? String)

    mediaProvider.loadMedia { (mediaEntry, error) in
      if let error = error {
        print("[DEBUG] Error: \(error.localizedDescription)")
        return
      }

      guard let mediaEntry = mediaEntry else {
        print("[DEBUG] MediaEntry: NIL")
        return
      }

      let mediaConfig = MediaConfig(mediaEntry: mediaEntry)
      print("[DEBUG] MediaEntry: \(mediaEntry)")
      self.player.prepare(mediaConfig)
    }

    result(nil)
  }

  private func onOrientationChanged(arguments: Any?, result: FlutterResult) {
    //    newSize["width"] = width;
    //    newSize["height"] = height;
    result(nil)
  }

  private func onSizeChanged(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func isPlaying(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func play(arguments: Any?, result: FlutterResult) {
    player.play()
    result(nil)
  }

  private func pause(arguments: Any?, result: FlutterResult) {
    player.pause()
    result(nil)
  }

  private func toggleVRMode(arguments: Any?, result: FlutterResult) {
    guard let vrController = self.player.getController(ofType: PKVRController.self) else {
        return
    }
    vrController.setVRModeEnabled(true)

    result(nil)
  }

  private func seekTo(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func onPause(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func onResume(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

}

class KalturaFlutterEventChannel: NSObject, FlutterStreamHandler {

  private let playerEngine: Player
  private let playerEvents: [PKEvent.Type]

  private let eventChannelName: String
  private let eventChannel: FlutterEventChannel
  private(set) var eventSink: FlutterEventSink?

  init(
    name: String,
    binaryMessenger messenger: FlutterBinaryMessenger,
    player: Player,
    playerEvents: [PKEvent.Type] = []
  ) {

    self.playerEngine = player
    self.playerEvents = playerEvents
    self.eventChannelName = name
    self.eventChannel = FlutterEventChannel(name: name, binaryMessenger: messenger)

    super.init()

    eventChannel.setStreamHandler(self)

    playerEngine.addObserver(self, events: playerEvents) { (playerEventData) in
      print("ios: FlutterEventChannel: \(self.eventChannelName) PlayerEventData: \(playerEventData)")
    }
  }

  func onListen(withArguments arguments: Any?, eventSink events: @escaping FlutterEventSink) -> FlutterError? {
    print(#function)
    eventSink = events
    if let arguments = arguments {
      print(arguments)
    }
    return nil
  }

  func onCancel(withArguments arguments: Any?) -> FlutterError? {
    print(#function)
    eventSink = nil
    playerEngine.removeObserver(self, events: playerEvents)
    if let arguments = arguments {
      print(arguments)
    }
    return nil
  }

}

==> 0.0.5.tar.gz: ios/Classes/PlayerFlutterView.swift <==
//
//  PlayerFlutterView.swift
//  KalturaNetKit
//

import Flutter
import PlayKit
import PlayKitProviders

final class PlayerFlutterViewFactory: NSObject, FlutterPlatformViewFactory {

  static let factoryIdentifier: String = "plugins.video_360_kaltura/player_view"

  private let messenger: FlutterBinaryMessenger

  init(messenger: FlutterBinaryMessenger) {
    self.messenger = messenger
    super.init()
  }

  func create(withFrame frame: CGRect, viewIdentifier viewId: Int64, arguments args: Any?) -> FlutterPlatformView {

    let playerFlutterView = PlayerFlutterView(
      frame: frame,
      viewId: viewId,
      arguments: args as? [String : Any],
      messenger: messenger
    )

    return playerFlutterView
  }

  func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
    return FlutterStandardMessageCodec.sharedInstance()
  }

}

final class PlayerFlutterView: NSObject, FlutterPlatformView {

  private let viewId: Int64

  private let args: Dictionary<String, Any>?
  private let serverUrl: String?
  private let partnerID: String?

  private let player: Player = PlayKitManager.shared.loadPlayer(pluginConfig: nil)
  private let flutterView: PlayerView

  private let channel: FlutterMethodChannel
  private let flutterChannels: [KalturaFlutterEventChannel]

  init(frame: CGRect, viewId: Int64, arguments: [String: Any]?, messenger: FlutterBinaryMessenger) {
    self.viewId = viewId;
    self.args = arguments

    self.serverUrl = arguments?["ovpServerUrl"] as? String
    self.partnerID = arguments?["partnerId"] as? String

    self.channel = FlutterMethodChannel(
      name: String(format: "video360Kaltura_%lld", viewId),
      binaryMessenger: messenger
    )

    flutterChannels = [
      KalturaStateEventChannel(
        name: String(format: "video360Kaltura_events_%lld_state", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: [PlayerEvent.stateChanged]
      ),
      KalturaDurationEventChannel(
        name: String(format: "video360Kaltura_events_%lld_duration", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: [PlayerEvent.durationChanged]
      ),
      KalturaPositionEventChannel(
        name: String(format: "video360Kaltura_events_%lld_position", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: PlayerEvent.allEventTypes
      ),
      KalturaEndedEventChannel(
        name: String(format: "video360Kaltura_events_%lld_ended", viewId),
        binaryMessenger: messenger,
        player: player,
        playerEvents: [PlayerEvent.ended]
      )
    ]

    let viewFrame = CGRect(
      x: CGFloat(args?["x"] as? Double ?? 0.0),
      y: CGFloat(args?["y"] as? Double ?? 0.0),
      width: CGFloat(args?["width"] as? Double ?? 0.0),
      height: CGFloat(args?["height"] as? Double ?? 0.0)
    )

    flutterView = PlayerView(frame: viewFrame)
    player.view = flutterView

    super.init()

    self.channel.setMethodCallHandler(methodCallback)
  }

  func view() -> UIView {
    return flutterView
  }

  //MARK: FlutterMethodChannel
  func methodCallback(call: FlutterMethodCall, result: FlutterResult)  {

    #if DEBUG
//    NSLog("ios: FlutterMethod %@ - Arguments -> %@", call.method, call.arguments.debugDescription)
    #endif

    switch call.method {
    case "loadVideo":
      loadVideo(arguments: call.arguments as? [String: Any], result: result)
    case "onOrientationChanged":
      onOrientationChanged(arguments: call.arguments, result: result)
    case "onSizeChanged":
      onSizeChanged(arguments: call.arguments, result: result)
    case "isPlaying":
      isPlaying(arguments: call.arguments, result: result)
    case "play":
      play(arguments: call.arguments, result: result)
    case "pause":
      pause(arguments: call.arguments, result: result)
    case "toggleVRMode":
      toggleVRMode(arguments: call.arguments, result: result)
    case "seekTo":
      seekTo(arguments: call.arguments, result: result)
    case "onPause":
      onPause(arguments: call.arguments, result: result)
    case "onResume":
      onResume(arguments: call.arguments, result: result)
    default:
      methodCall(arguments: call.arguments, result: result)
    }
  }

  private func methodCall(arguments: Any?, result: FlutterResult) {
    result(FlutterMethodNotImplemented)
  }

  private func loadVideo(arguments: [String: Any]?, result: FlutterResult) {

    PlayKitManager.logLevel = .info

    guard let serverUrl = serverUrl else {
      result(FlutterError(code: "Server URL is required", message: nil, details: nil))
      return
    }

    guard let partnerID = partnerID else {
      result(FlutterError(code: "Partner Identifier is required", message: nil, details: nil))
      return
    }

    let sessionProvider: SimpleSessionProvider = SimpleSessionProvider(
      serverURL: serverUrl,
      partnerId: Int64(partnerID) ?? 0,
      ks: nil
    )

    let mediaProvider: OVPMediaProvider = OVPMediaProvider(sessionProvider)
    mediaProvider.set(entryId: arguments?["entryId"] as? String)

    mediaProvider.loadMedia { (mediaEntry, error) in
      if let error = error {
        print("[DEBUG] Error: \(error.localizedDescription)")
        return
      }

      guard let mediaEntry = mediaEntry else {
        print("[DEBUG] MediaEntry: NIL")
        return
      }

      let mediaConfig = MediaConfig(mediaEntry: mediaEntry)
      print("[DEBUG] MediaEntry: \(mediaEntry)")
      self.player.prepare(mediaConfig)
    }

    result(nil)
  }

  private func onOrientationChanged(arguments: Any?, result: FlutterResult) {
    //    newSize["width"] = width;
    //    newSize["height"] = height;
    result(nil)
  }

  private func onSizeChanged(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func isPlaying(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func play(arguments: Any?, result: FlutterResult) {
    player.play()
    result(nil)
  }

  private func pause(arguments: Any?, result: FlutterResult) {
    player.pause()
    result(nil)
  }

  private func toggleVRMode(arguments: Any?, result: FlutterResult) {
    guard let vrController = self.player.getController(ofType: PKVRController.self) else {
        return
    }
    vrController.setVRModeEnabled(true)

    result(nil)
  }

  private func seekTo(arguments: Any?, result: FlutterResult) {

    guard let arguments = arguments as? [String: Any] else {
      result(nil)
      return
    }

    let seekTimeInterval: TimeInterval
    if let timePostion = arguments["position"] as? TimeInterval {
      seekTimeInterval = timePostion / 1_000.0
    } else {
      seekTimeInterval = 0.0
    }

    player.seek(to: seekTimeInterval)

    result(nil)
  }

  private func onPause(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

  private func onResume(arguments: Any?, result: FlutterResult) {
    result(nil)
  }

}

class KalturaFlutterEventChannel: NSObject, FlutterStreamHandler {

  internal let playerEngine: Player
  private let playerEvents: [PKEvent.Type]

  let eventChannelName: String
  private let eventChannel: FlutterEventChannel
  private(set) var eventSink: FlutterEventSink?

  init(
    name: String,
    binaryMessenger messenger: FlutterBinaryMessenger,
    player: Player,
    playerEvents: [PKEvent.Type] = []
  ) {

    self.playerEngine = player
    self.playerEvents = playerEvents
    self.eventChannelName = name
    self.eventChannel = FlutterEventChannel(name: name, binaryMessenger: messenger)

    super.init()

    eventChannel.setStreamHandler(self)

    playerEngine.addObserver(self, events: playerEvents, block: playerEventListener)
  }

  func playerEventListener(playerEvent: PKEvent) { }

  func onListen(withArguments arguments: Any?, eventSink events: @escaping FlutterEventSink) -> FlutterError? {
    print(#function)
    eventSink = events
    if let arguments = arguments {
      print(arguments)
    }
    return nil
  }

  func onCancel(withArguments arguments: Any?) -> FlutterError? {
    print(#function)
    eventSink = nil
    playerEngine.removeObserver(self, events: playerEvents)
    if let arguments = arguments {
      print(arguments)
    }
    return nil
  }

}

class KalturaStateEventChannel: KalturaFlutterEventChannel {

  override func playerEventListener(playerEvent: PKEvent) {

    let state: Int
    switch playerEngine.currentState {
    case .idle:
      state = 0
    case .ready:
      state = 1
    default:
      state = 2
    }

    let eventResponse = [
      "state": state
    ]

    eventSink?(eventResponse)
  }

}

class KalturaDurationEventChannel: KalturaFlutterEventChannel {

  override func playerEventListener(playerEvent: PKEvent) {

    let eventResponse = [
      "duration": NSNumber(value: 1000.0 * playerEngine.duration).intValue,
    ]

    eventSink?(eventResponse)
  }

}

class KalturaPositionEventChannel: KalturaFlutterEventChannel {

  override func playerEventListener(playerEvent: PKEvent) {

    let eventResponse = [
        "currentPosition": NSNumber(value: 1000.0 * playerEngine.currentTime).intValue,
    ]

    eventSink?(eventResponse)
  }

}

class KalturaEndedEventChannel: KalturaFlutterEventChannel {

  override func playerEventListener(playerEvent: PKEvent) {

    let eventResponse = [
      "ended": playerEngine.currentState == PlayerState.ended,
    ]

    eventSink?(eventResponse)
  }

}
